<!--
  Licensed to the Apache Software Foundation (ASF) under one or more
  contributor license agreements.  See the NOTICE file distributed with
  this work for additional information regarding copyright ownership.
  The ASF licenses this file to You under the Apache License, Version 2.0
  (the "License"); you may not use this file except in compliance with
  the License.  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
-->
<!DOCTYPE html>
<html>
<head>
    <title>Auth Example</title>
    <script type="text/javascript">
        var ws = null;
		var connected = false;
		var loggedin = false;
        function setLoggedIn(connected) {
        	loggedin = connected;
            document.getElementById('connect').disabled = connected;
            document.getElementById('disconnect').disabled = !connected;
            document.getElementById('ping').disabled = !connected;
            document.getElementById('echo').disabled = !connected;
        }

        function connect() {
        	status('Connecting...');
            var target = document.getElementById('target').value;
            if (target == '') {
                return;
            }
            if ('WebSocket' in window) {
                ws = new WebSocket(target);
            } else if ('MozWebSocket' in window) {
                ws = new MozWebSocket(target);
            } else {
                alert('WebSocket is not supported by this browser.');
                return;
            }
            ws.onopen = function () {
                connected = true;
                status('Connected, logging in');
                login();
            };
            ws.onmessage = function (event) {
            	if(!loggedin){
            		if(event.data=='true'){
            			setLoggedIn(true);
            			status('Logged in');
            		}else if(event.data=='false'){
            			status('Login failed');
            		}
            	}else{
            		if(event.data=='pong'){
            			alert('PONG');
            		}else{
                		log('Received: ' + event.data);
            		}
            	}
            };
            ws.onclose = function () {
            	ws.send("logout");
                connected = false;
                setLoggedIn(false);
                status('Logged out');
            };
        }
        
        function login(){
        	var message = 'login-' + document.getElementById('username').value + '-' + document.getElementById('password').value;
        	ws.send(message);
        }

        function disconnect() {
        	ws.send("logout");
            if (ws != null) {
                ws.close();
                ws = null;
            }
            setLoggedIn(false);
            connected = false;
            status('Disconnected');
            
        }
        function ping(){
        	ws.send("ping");
        }
		function status(message){
			var status = document.getElementById('status');
			var p = document.createElement('p');
            p.style.wordWrap = 'break-word';
            p.appendChild(document.createTextNode(message));
			status.appendChild(p);
			while (status.childNodes.length > 1) {
                status.removeChild(status.firstChild);
            }
		}
        function log(message) {
            var console = document.getElementById('console');
            var p = document.createElement('p');
            p.style.wordWrap = 'break-word';
            p.appendChild(document.createTextNode(message));
            console.appendChild(p);
            while (console.childNodes.length > 25) {
                console.removeChild(console.firstChild);
            }
            console.scrollTop = console.scrollHeight;
        }
    </script>
</head>
<body>
<noscript><h2 style="color: #ff0000">Seems your browser doesn't support Javascript! Websockets rely on Javascript being enabled. Please enable
    Javascript and reload this page!</h2></noscript>
<div>
    <div id="connect-container">
        <div>
            Target <input id="target" type="text" size="40" style="width: 350px" value="ws://hyperbadger.it.cx:8000/WebAuth/WS"/>
        </div>
        <div>
        	Username <input type="text" id="username"/>
        	Password <input type="text" id="password"/>
        </div>
        <div>
            <button id="connect" onclick="connect();">Login</button>
            <button id="disconnect" disabled="disabled" onclick="disconnect();">Logout</button>
            <button id="ping" disabled="disabled" onclick="ping();">Ping</button>
        </div>
    </div>
    <div id="console-container">
    	<div id="status"></div>
        <div id="console"></div>
    </div>
</div>
</body>
</html>